@@ -1,63 +1,48 @@
-# -*- coding: utf-8 -*-
-
-"""Code to safely list, download and upload storage bucket files."""
-
 from attr import dataclass
 from google.cloud.storage import Bucket, Client
-from returns.functions import raise_exception
-from returns.pipeline import pipeline
-from returns.result import ResultE, safe
 from typing_extensions import final
 
+from storage_bucket.client import GetClient
+
 
 @final
 @dataclass(frozen=True, slots=True)
 class CreateBucket(object):
     """Create a gcp storage bucket."""
 
-    _client = Client
-    _bucket = Bucket
+    get_client = GetClient()
 
-    @pipeline(ResultE)
     def __call__(
         self,
         storage_bucket_name: str,
         location: str,
         storage_class: str = 'STANDARD',
-    ) -> ResultE[Bucket]:
+    ) -> Bucket:
         """List the storage bucket files."""
-        client = self._initialize_client().unwrap()  # type: ignore
-        bucket = self._initialize_bucket(  # type: ignore
-            client,
-            storage_bucket_name,
-            storage_class,
-        ).unwrap()
+        client = self.get_client()
 
-        return self._create_bucket(client, bucket, location)  # type: ignore
+        return self._create_bucket(
+            client=client,
+            name=storage_bucket_name,
+            storage_class=storage_class,
+            location=location,
+        )
 
-    @safe
     def _create_bucket(
         self,
+        *,
         client: Client,
-        bucket: Bucket,
+        name: str,
+        storage_class: str,
         location: str,
-    ) -> Bucket:
-        return client.create_bucket(bucket, location=location)
-
-    @safe
-    def _initialize_bucket(
-        self, client: Client, name: str, storage_class: str,
     ) -> Bucket:
         bucket = Bucket(client, name=name)
         bucket.storage_class = storage_class
-        return bucket
-
-    @safe
-    def _initialize_client(self) -> Client:
-        return self._client()
+        return client.create_bucket(bucket, location=location)
 
 
 def create_bucket(
+    *,
     storage_bucket_name: str,
     location: str,
     storage_class: str = 'STANDARD',
@@ -70,6 +55,4 @@ def create_bucket(
         storage_bucket_name=storage_bucket_name,
         location=location,
         storage_class=storage_class,
-    ).alt(
-        raise_exception,
-    ).unwrap()
+    )
