@@ -1,14 +1,4 @@
-# -*- coding: utf-8 -*-
-
-"""Code to safely download storage bucket files."""
-from functools import partial
-from typing import Optional, Tuple, Union
-
 from attr import dataclass
-from google.cloud.storage import Bucket
-from returns.functions import raise_exception
-from returns.pipeline import pipeline
-from returns.result import ResultE, safe
 from typing_extensions import final
 
 from storage_bucket.get import GetBucket
@@ -37,38 +27,31 @@ class DeleteFile(object):
     :return: Result[None, Exception]
     """
 
-    _get_bucket = GetBucket()
+    get_bucket = GetBucket()
 
-    @pipeline(ResultE)
-    def __call__(  # noqa: WPS234  fix annotation with a timeout type
+    def __call__(
         self,
         storage_bucket_name: str,
         filename: str,
-        generation: Optional[int] = None,
-        timeout: Optional[Union[int, Tuple[int, int]]] = None,
-    ) -> ResultE[None]:
+        **kwargs,
+    ) -> None:
         """Delete storage bucket file."""
-        return self._get_bucket(
-            storage_bucket_name,
-        ).bind(
-            partial(self._delete_file, filename=filename),
-        )
+        bucket = self.get_bucket(storage_bucket_name=storage_bucket_name)
 
-    @safe
-    def _delete_file(self, bucket: Bucket, filename: str) -> None:
-        bucket.delete_blob(filename)
+        bucket.delete_blob(
+            filename,
+            **kwargs,
+        )
 
 
 def delete_file(
     storage_bucket_name: str,
     filename: str,
-    generation: Optional[int] = None,
+    **kwargs,
 ) -> None:
     """Delete file with DeleteFile but raise exception on failure."""
     DeleteFile()(
         storage_bucket_name=storage_bucket_name,
         filename=filename,
-        generation=generation,
-    ).alt(
-        raise_exception,
-    ).unwrap()
+        **kwargs,
+    )
