@@ -1,12 +1,4 @@
-# -*- coding: utf-8 -*-
-
-"""Code to safely download storage bucket files."""
-
 from attr import dataclass
-from google.cloud.storage import Blob, Bucket
-from returns.functions import raise_exception
-from returns.pipeline import pipeline
-from returns.result import ResultE, safe
 from typing_extensions import final
 
 from storage_bucket.get import GetBucket
@@ -29,36 +21,29 @@ class DownloadFile(object):
     :return: Result[bytes, Exception]
     """
 
-    _get_bucket = GetBucket()
+    get_bucket = GetBucket()
 
-    @pipeline(ResultE)
     def __call__(
         self,
+        *,
         storage_bucket_name: str,
         filename: str,
-    ) -> ResultE[bytes]:
+    ) -> bytes:
         """Download storage bucket file."""
-        bucket = self._get_bucket(storage_bucket_name).unwrap()
-        blob = self._get_blob(bucket, filename).unwrap()
-        return self._get_bytes(blob)
+        bucket = self.get_bucket(storage_bucket_name=storage_bucket_name)
 
-    @safe
-    def _get_blob(self, bucket: Bucket, filename: str) -> object:
-        return bucket.blob(filename)
+        blob = bucket.blob(filename)
 
-    @safe
-    def _get_bytes(self, blob: Blob) -> bytes:
-        return blob.download_as_string()
+        return blob.download_as_bytes()
 
 
 def download_file(
+    *,
     storage_bucket_name: str,
     filename: str,
 ) -> bytes:
     """Download file as per usual but raise exception on error."""
     return DownloadFile()(
-        storage_bucket_name,
-        filename,
-    ).alt(
-        raise_exception,
-    ).unwrap()
+        storage_bucket_name=storage_bucket_name,
+        filename=filename,
+    )
