@@ -1,39 +1,34 @@
-# -*- coding: utf-8 -*-
-
-"""Code to safely list storage bucket files."""
-
 from typing import Optional, Set
 
 from attr import dataclass
 from google.cloud.storage import Blob, Client
-from returns.functions import raise_exception
-from returns.pipeline import pipeline
-from returns.result import ResultE, safe
 from typing_extensions import final
 
+from storage_bucket.client import GetClient
+
 
 @final
 @dataclass(frozen=True, slots=True)
 class ListFiles(object):
     """List all blobs in given storage_bucket."""
 
-    _client = Client
+    get_client = GetClient()
 
-    @pipeline(ResultE)
     def __call__(
         self,
+        *,
         storage_bucket_name: str,
         prefix: Optional[str] = None,
-    ) -> ResultE[Set[Blob]]:
+    ) -> Set[Blob]:
         """List the storage bucket files."""
-        client = self._initialize_client().unwrap()  # type: ignore
+        client = self.get_client()
+
         return self._list_blobs(
-            client,
-            storage_bucket_name,
-            prefix,
+            client=client,
+            storage_bucket_name=storage_bucket_name,
+            prefix=prefix,
         )
 
-    @safe
     def _list_blobs(
         self,
         client: Client,
@@ -42,19 +37,14 @@ class ListFiles(object):
     ) -> Set[Blob]:
         return set(client.list_blobs(storage_bucket_name, prefix=prefix))
 
-    @safe
-    def _initialize_client(self) -> Client:
-        return self._client()
-
 
 def list_files(
+    *,
     storage_bucket_name: str,
     prefix: Optional[str] = None,
 ) -> Set[Blob]:
     """Download file as per usual but raise exception on error."""
     return ListFiles()(
-        storage_bucket_name,
-        prefix,
-    ).alt(
-        raise_exception,
-    ).unwrap()
+        storage_bucket_name=storage_bucket_name,
+        prefix=prefix,
+    )
