@@ -1,12 +1,4 @@
-# -*- coding: utf-8 -*-
-
-"""Code to safely upload storage bucket files."""
-
 from attr import dataclass
-from google.cloud.storage import Blob, Bucket
-from returns.functions import raise_exception
-from returns.pipeline import pipeline
-from returns.result import ResultE, safe
 from typing_extensions import final
 
 from storage_bucket.get import GetBucket
@@ -35,46 +27,36 @@ class UploadFile(object):
     :return: Result[None, Exception]
     """
 
-    _get_bucket = GetBucket()
+    get_bucket = GetBucket()
 
-    @pipeline(ResultE)
     def __call__(
         self,
-        file_data: bytes,
+        file_content: bytes,
         storage_bucket_name: str,
         filename: str,
-        content_type: str = 'application/octet-stream',
-    ) -> ResultE[None]:
-        """Download storage bucket file."""
-        bucket = self._get_bucket(storage_bucket_name).unwrap()
-        blob = self._get_blob(bucket, filename).unwrap()
-        return self._upload_data(blob, file_data, content_type)
-
-    @safe
-    def _get_blob(
-        self, bucket: Bucket, filename: str,
-    ) -> object:
-        return bucket.blob(filename)
-
-    @safe
-    def _upload_data(
-        self, blob: Blob, file_content: bytes, content_type: str,
+        **kwargs,
     ) -> None:
-        blob.upload_from_string(file_content, content_type)
+        """Download storage bucket file."""
+        bucket = self.get_bucket(storage_bucket_name=storage_bucket_name)
+
+        blob = bucket.blob(filename)
+        blob.upload_from_string(
+            file_content,
+            **kwargs,
+        )
 
 
 def upload_file(
-    file_data: bytes,
+    *,
+    file_content: bytes,
     storage_bucket_name: str,
     filename: str,
     content_type: str = 'application/octet-stream',
 ) -> None:
     """Upload file as per usual but raise exception on error."""
     return UploadFile()(
-        file_data,
-        storage_bucket_name,
-        filename,
-        content_type,
-    ).alt(
-        raise_exception,
-    ).unwrap()
+        file_content=file_content,
+        storage_bucket_name=storage_bucket_name,
+        filename=filename,
+        content_type=content_type,
+    )
